==> qddate-1.0.2.tar.gz: qddate-1.0.2/setup.py <==
import re
import io
from setuptools import setup, find_packages

open_as_utf = lambda x: io.open(x, encoding='utf-8')

(__version__, ) = re.findall("__version__.*\s*=\s*[']([^']+)[']", open('qddate/__init__.py').read())

#readme = re.sub(r':members:.+|..\sautomodule::.+|:class:|:func:', '', open_as_utf('README.rst').read())
#readme = re.sub(r'`Settings`_', '`Settings`', readme)
#readme = re.sub(r'`Contributing`_', '`Contributing`', readme)
readme = open_as_utf('README.rst').read()
#history = re.sub(r':mod:|:class:|:func:', '', open_as_utf('HISTORY.rst').read())
history = open_as_utf('HISTORY.rst').read()



setup(
    name='qddate',
    version=__version__,
    description='Quick and dirty date parsing Python library to parse HTML dates really fast',
#    long_description=readme + '\n\n' + history,
    long_description='Quick and dirty date parsing Python library to parse HTML dates really fast',
    author='Ivan Begtin',
    author_email='ivan@begtin.tech',
    url='https://github.com/ivbeg/qddate',
    packages=find_packages(exclude=('tests', 'tests.*')),
    include_package_data=True,
    install_requires=[
        'dateparser>=1.1.0',
        'pyparsing>=2.4.7'
    ],
    python_requires='>=3.8',
    license="BSD",
    zip_safe=False,
    keywords='date datetime',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy'
    ]
)

==> qddate-1.0.3.tar.gz: qddate-1.0.3/setup.py <==
import re
import io
from setuptools import setup, find_packages

open_as_utf = lambda x: io.open(x, encoding='utf-8')

(__version__, ) = re.findall("__version__.*\s*=\s*[']([^']+)[']", open('qddate/__init__.py').read())

readme = re.sub(r':members:.+|..\sautomodule::.+|:class:|:func:', '', open_as_utf('README.rst').read())
readme = re.sub(r'`Settings`_', '`Settings`', readme)
readme = re.sub(r'`Contributing`_', '`Contributing`', readme)
readme = open_as_utf('README.rst').read()
history = re.sub(r':mod:|:class:|:func:', '', open_as_utf('HISTORY.rst').read())



setup(
    name='qddate',
    version=__version__,
    description='Quick and dirty date parsing Python library to parse HTML dates really fast',
    long_description=readme + '\n\n\n' + history,
    author='Ivan Begtin',
    author_email='ivan@begtin.tech',
    url='https://github.com/ivbeg/qddate',
    packages=find_packages(exclude=('tests', 'tests.*')),
    include_package_data=True,
    install_requires=[
        'dateparser>=1.1.0',
        'pyparsing>=2.4.7'
    ],
    python_requires='>=3.8',
    license="BSD",
    zip_safe=False,
    keywords='date datetime',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy'
    ]
)
